function [x, xf]=percept_model(seg, N, Fs)
% Map audio frame seg to N-point 0:(Fs/2)Hz percept model. N typically 40 at Fs = 8 kHz
b_low=0; %Bark span lower limit
b_top=f2bark(Fs/2); %Bark span upper limit
bdiv=(b_top-b_low)/N; %Bark resolution
%Define an array of centre frequencies
xb=b_low+bdiv/2:bdiv:b_top-bdiv/2;
xf=bark2f(xb); %Convert to Hz
S=abs(fft(seg));
S=S(1:length(S)/2);
F=[1:length(S)]*(Fs/2)/length(S);
x=zeros(1,N);
for xi=1:N
    bark=xb(xi);
    hz=bark2f(bark);
    %compute spreading function
    spr=spread_hz(F,hz);
    %compute summed influence
    x_sum=sum(spr.*S')*equal_loudness_preemph(hz);
    %intensity loudness power law
    x(xi)=(x_sum)^0.33;
end